@@ -168,7 +168,7 @@ sub compress {
     # Upper bound
     my $U = $L + $pf;
 
-    my $pow = $pf->log(2)->as_int;
+    my $pow = $pf->log2->as_int;
     my $enc = ($U - 1) >> $pow;
 
     # Remove any divisibility by 2
@@ -249,7 +249,7 @@ sub decompress {
     open my $out_fh, '>:raw', $output;
 
     # Decode the input number
-    for (my $pow = Math::BigNum->new($base)**($base - 1) ; $pow->is_pos ; $pow->bidiv($base)) {
+    for (my ($i, $pow) = (0, Math::BigNum->new($base)->bipow($base - 1)) ; $i < $base ; ++$i, $pow->bidiv($base)) {
         my $div = $enc->idiv($pow);
 
         my $c  = $dict{$div};
