@@ -9,7 +9,7 @@ use Math::BigNum qw();
 
 use Class::Multimethods qw();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =encoding utf8
 
@@ -19,7 +19,7 @@ Math::BigNum::Inf - Represents the +/-Infinity value.
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SYNOPSIS
 
@@ -1593,6 +1593,8 @@ Class::Multimethods::multimethod brsft => qw(Math::BigNum::Inf Math::BigNum::Nan
 
 *bernreal  = \&nan;
 *bernfrac  = \&nan;
+*harmfrac  = \&nan;
+*harmreal  = \&nan;
 *kronecker = \&nan;
 *valuation = \&nan;
 
@@ -1648,9 +1650,7 @@ sub zeta {
 }
 
 sub erfc {
-    $_[0]->is_pos ? zero() : do {
-        state $x = one()->add(one());
-    };
+    $_[0]->is_pos ? zero() : one()->blsft(1);
 }
 
 sub fac {
@@ -1702,4 +1702,7 @@ sub as_bin { $_[0]->is_pos ? 'Inf' : '-Inf' }
 sub digits { () }
 sub length { 0 }
 
+sub seed { }
+*iseed = \&seed;
+
 1;
