@@ -7,7 +7,7 @@ use warnings;
 use Math::GMPq qw();
 use Math::BigNum qw();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =encoding utf8
 
@@ -17,7 +17,7 @@ Math::BigNum::Nan - Represents the Not-a-Number value.
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SYNOPSIS
 
@@ -454,8 +454,10 @@ sub length { 0 }
 *dfac      = \&nan;
 *lucas     = \&nan;
 *binomial  = \&nan;
-*bernreal  = \&nan;
 *bernfrac  = \&nan;
+*bernreal  = \&nan;
+*harmfrac  = \&nan;
+*harmreal  = \&nan;
 *kronecker = \&nan;
 *valuation = \&nan;
 
@@ -480,4 +482,7 @@ sub divmod { (nan(), nan()) }
 
 *parts = \&divmod;
 
+sub seed { }
+*iseed = \&seed;
+
 1;
